import { CSSObject } from 'styled-components';
declare type ExtraPartial<T> = {
    [P in keyof T]?: T[P] extends Record<infer K, infer U> ? Partial<T[P]> : T[P];
};
export declare type HiroColors = 'primary' | 'secondary' | 'primaryText' | 'secondaryText' | 'red' | 'orange' | 'yellow' | 'green' | 'teal' | 'blue' | 'purple' | 'pink' | 'brown' | 'black' | 'grey' | 'white';
export declare type Greyscales = 'lightest' | 'lighter' | 'light' | 'medium' | 'dark' | 'darker' | 'darkest';
export interface BreakpointDefinitions {
    sm: number;
    md: number;
    lg: number;
    xl: number;
}
export declare type ColorDefinitionValuesEnum = 'default' | 'active' | 'hover' | 'light' | 'dark' | 'verylight' | 'highlighted' | 'highlightedHover' | 'saturated' | 'disabled' | 'transparent' | 'verytransparent';
export declare type ColorDefinitionValues = Record<ColorDefinitionValuesEnum, string>;
export declare type SizeScale = 'mini' | 'tiny' | 'small' | 'medium' | 'large' | 'big' | 'huge' | 'massive';
export declare type ColorDefinitions = Record<HiroColors, ColorDefinitionValues>;
export interface FontDefinitons {
    h1: CSSObject;
    h2: CSSObject;
    h3: CSSObject;
}
export declare type GreyscaleDefinitions = {
    [K in Greyscales]: string;
};
export interface SizeDefinitions {
    borderRadius: string | number;
    borderRadiusInput: string | number;
    padding: Record<'normal' | 'extra', string>;
    scale: Record<SizeScale, number>;
    width: BreakpointDefinitions;
}
export interface HiroDefaultTheme {
    breakpoints: BreakpointDefinitions;
    colors: Record<HiroColors, string>;
    font: FontDefinitons;
    global: CSSObject;
    greyscale: GreyscaleDefinitions;
    sizes: SizeDefinitions;
}
export interface HiroPartialTheme {
    breakpoints?: ExtraPartial<BreakpointDefinitions>;
    colors?: ExtraPartial<Record<HiroColors, string>>;
    font?: ExtraPartial<FontDefinitons>;
    global?: CSSObject;
    greyscale?: ExtraPartial<GreyscaleDefinitions>;
    sizes?: ExtraPartial<SizeDefinitions>;
}
export interface DefaultTheme {
    breakpoints: BreakpointDefinitions;
    colors: ColorDefinitions;
    font: FontDefinitons;
    global: CSSObject;
    greyscale: GreyscaleDefinitions;
    sizes: SizeDefinitions;
}
declare module 'styled-components' {
    interface DefaultTheme {
        breakpoints: BreakpointDefinitions;
        colors: ColorDefinitions;
        font: FontDefinitons;
        global: CSSObject;
        greyscale: GreyscaleDefinitions;
        sizes: SizeDefinitions;
    }
}
export declare type HiroIcons = '500px' | 'adjust' | 'adn' | 'align-center' | 'align-justify' | 'align-left' | 'align-right' | 'amazon' | 'ambulance' | 'anchor' | 'android' | 'angellist' | 'angle-double-down' | 'angle-double-left' | 'angle-double-right' | 'angle-double-up' | 'angle-down' | 'angle-left' | 'angle-right' | 'angle-up' | 'apple' | 'archive' | 'area-chart' | 'arrow-circle-down' | 'arrow-circle-left' | 'arrow-circle-o-down' | 'arrow-circle-o-left' | 'arrow-circle-o-right' | 'arrow-circle-o-up' | 'arrow-circle-right' | 'arrow-circle-up' | 'arrow-down' | 'arrow-left' | 'arrow-right' | 'arrow-up' | 'arrows-alt' | 'arrows-h' | 'arrows-v' | 'arrows' | 'asterisk' | 'at' | 'backward' | 'balance-scale' | 'ban' | 'bar-chart' | 'barcode' | 'bars' | 'battery-empty' | 'battery-full' | 'battery-half' | 'battery-quarter' | 'battery-three-quarters' | 'bed' | 'beer' | 'behance-square' | 'behance' | 'bell-o' | 'bell-slash-o' | 'bell-slash' | 'bell' | 'bicycle' | 'binoculars' | 'birthday-cake' | 'bitbucket-square' | 'bitbucket' | 'black-tie' | 'bold' | 'bolt' | 'bomb' | 'book' | 'bookmark-o' | 'bookmark' | 'briefcase' | 'btc' | 'bug' | 'building-o' | 'building' | 'bullhorn' | 'bullseye' | 'bus' | 'buysellads' | 'calculator' | 'calendar-check-o' | 'calendar-minus-o' | 'calendar-o' | 'calendar-plus-o' | 'calendar-times-o' | 'calendar' | 'camera-retro' | 'camera' | 'car' | 'caret-down' | 'caret-left' | 'caret-right' | 'caret-square-o-down' | 'caret-square-o-left' | 'caret-square-o-right' | 'caret-square-o-up' | 'caret-up' | 'cart-arrow-down' | 'cart-plus' | 'cc-amex' | 'cc-diners-club' | 'cc-discover' | 'cc-jcb' | 'cc-mastercard' | 'cc-paypal' | 'cc-stripe' | 'cc-visa' | 'cc' | 'certificate' | 'chain-broken' | 'check-circle-o' | 'check-circle' | 'check-square-o' | 'check-square' | 'check' | 'chevron-circle-down' | 'chevron-circle-left' | 'chevron-circle-right' | 'chevron-circle-up' | 'chevron-down' | 'chevron-left' | 'chevron-right' | 'chevron-up' | 'child' | 'chrome' | 'circle-o-notch' | 'circle-o' | 'circle-thin' | 'circle' | 'clipboard' | 'clock-o' | 'clone' | 'cloud-download' | 'cloud-upload' | 'cloud' | 'code-fork' | 'code' | 'codepen' | 'coffee' | 'cog' | 'cogs' | 'columns' | 'comment-o' | 'comment' | 'commenting-o' | 'commenting' | 'comments-o' | 'comments' | 'compass' | 'compress' | 'connectdevelop' | 'contao' | 'copyright' | 'creative-commons' | 'credit-card' | 'crop' | 'crosshairs' | 'css3' | 'cube' | 'cubes' | 'cutlery' | 'dashcube' | 'database' | 'delicious' | 'desktop' | 'deviantart' | 'diamond' | 'digg' | 'dot-circle-o' | 'download' | 'dribbble' | 'dropbox' | 'drupal' | 'eject' | 'ellipsis-h' | 'ellipsis-v' | 'empire' | 'envelope-o' | 'envelope-square' | 'envelope' | 'eraser' | 'eur' | 'exchange' | 'exclamation-circle' | 'exclamation-triangle' | 'exclamation' | 'expand' | 'expeditedssl' | 'external-link-square' | 'external-link' | 'eye-slash' | 'eye' | 'eyedropper' | 'facebook-official' | 'facebook-square' | 'facebook' | 'fast-backward' | 'fast-forward' | 'fax' | 'female' | 'fighter-jet' | 'file-archive-o' | 'file-audio-o' | 'file-code-o' | 'file-excel-o' | 'file-image-o' | 'file-o' | 'file-pdf-o' | 'file-powerpoint-o' | 'file-text-o' | 'file-text' | 'file-video-o' | 'file-word-o' | 'file' | 'files-o' | 'film' | 'filter' | 'fire-extinguisher' | 'fire' | 'firefox' | 'flag-checkered' | 'flag-o' | 'flag' | 'flask' | 'flickr' | 'floppy-o' | 'folder-o' | 'folder-open-o' | 'folder-open' | 'folder' | 'font' | 'fonticons' | 'forumbee' | 'forward' | 'foursquare' | 'frown-o' | 'futbol-o' | 'gamepad' | 'gavel' | 'gbp' | 'genderless' | 'get-pocket' | 'gg-circle' | 'gg' | 'gift' | 'git-square' | 'git' | 'github-alt' | 'github-square' | 'github' | 'glass' | 'globe' | 'google-plus-square' | 'google-plus' | 'google-wallet' | 'google' | 'graduation-cap' | 'gratipay' | 'h-square' | 'hacker-news' | 'hand-lizard-o' | 'hand-o-down' | 'hand-o-left' | 'hand-o-right' | 'hand-o-up' | 'hand-paper-o' | 'hand-peace-o' | 'hand-pointer-o' | 'hand-rock-o' | 'hand-scissors-o' | 'hand-spock-o' | 'hdd-o' | 'header' | 'headphones' | 'heart-o' | 'heart' | 'heartbeat' | 'history' | 'home' | 'hospital-o' | 'hourglass-end' | 'hourglass-half' | 'hourglass-o' | 'hourglass-start' | 'hourglass' | 'houzz' | 'html5' | 'i-cursor' | 'ils' | 'inbox' | 'indent' | 'industry' | 'info-circle' | 'info' | 'inr' | 'instagram' | 'internet-explorer' | 'ioxhost' | 'italic' | 'joomla' | 'jpy' | 'jsfiddle' | 'key' | 'keyboard-o' | 'krw' | 'language' | 'laptop' | 'lastfm-square' | 'lastfm' | 'leaf' | 'leanpub' | 'lemon-o' | 'level-down' | 'level-up' | 'life-ring' | 'lightbulb-o' | 'line-chart' | 'link' | 'linkedin-square' | 'linkedin' | 'linux' | 'list-alt' | 'list-ol' | 'list-ul' | 'list' | 'location-arrow' | 'lock' | 'long-arrow-down' | 'long-arrow-left' | 'long-arrow-right' | 'long-arrow-up' | 'magic' | 'magnet' | 'male' | 'map-marker' | 'map-o' | 'map-pin' | 'map-signs' | 'map' | 'mars-double' | 'mars-stroke-h' | 'mars-stroke-v' | 'mars-stroke' | 'mars' | 'maxcdn' | 'meanpath' | 'medium' | 'medkit' | 'meh-o' | 'mercury' | 'microphone-slash' | 'microphone' | 'minus-circle' | 'minus-square-o' | 'minus-square' | 'minus' | 'mobile' | 'money' | 'moon-o' | 'motorcycle' | 'mouse-pointer' | 'music' | 'neuter' | 'newspaper-o' | 'object-group' | 'object-ungroup' | 'odnoklassniki-square' | 'odnoklassniki' | 'opencart' | 'openid' | 'opera' | 'optin-monster' | 'outdent' | 'pagelines' | 'paint-brush' | 'paper-plane-o' | 'paper-plane' | 'paperclip' | 'paragraph' | 'pause' | 'paw' | 'paypal' | 'pencil-square-o' | 'pencil-square' | 'pencil' | 'phone-square' | 'phone' | 'picture-o' | 'pie-chart' | 'pied-piper-alt' | 'pied-piper' | 'pinterest-p' | 'pinterest-square' | 'pinterest' | 'plane' | 'play-circle-o' | 'play-circle' | 'play' | 'plug' | 'plus-circle' | 'plus-square-o' | 'plus-square' | 'plus' | 'power-off' | 'print' | 'puzzle-piece' | 'qq' | 'qrcode' | 'question-circle' | 'question' | 'quote-left' | 'quote-right' | 'random' | 'rebel' | 'recycle' | 'reddit-square' | 'reddit' | 'refresh' | 'registered' | 'renren' | 'repeat' | 'reply-all' | 'reply' | 'retweet' | 'road' | 'rocket' | 'rss-square' | 'rss' | 'rub' | 'safari' | 'scissors' | 'search-minus' | 'search-plus' | 'search' | 'sellsy' | 'server' | 'share-alt-square' | 'share-alt' | 'share-square-o' | 'share-square' | 'share' | 'shield' | 'ship' | 'shirtsinbulk' | 'shopping-cart' | 'sign-in' | 'sign-out' | 'signal' | 'simplybuilt' | 'sitemap' | 'skyatlas' | 'skype' | 'slack' | 'sliders' | 'slideshare' | 'smile-o' | 'sort-alpha-asc' | 'sort-alpha-desc' | 'sort-amount-asc' | 'sort-amount-desc' | 'sort-asc' | 'sort-desc' | 'sort-numeric-asc' | 'sort-numeric-desc' | 'sort' | 'soundcloud' | 'space-shuttle' | 'spinner' | 'spoon' | 'spotify' | 'square-o' | 'square' | 'stack-exchange' | 'stack-overflow' | 'star-half-o' | 'star-half' | 'star-o' | 'star' | 'steam-square' | 'steam' | 'step-backward' | 'step-forward' | 'stethoscope' | 'sticky-note-o' | 'sticky-note' | 'stop' | 'street-view' | 'strikethrough' | 'stumbleupon-circle' | 'stumbleupon' | 'subscript' | 'subway' | 'suitcase' | 'sun-o' | 'superscript' | 'table' | 'tablet' | 'tachometer' | 'tag' | 'tags' | 'tasks' | 'taxi' | 'television' | 'tencent-weibo' | 'terminal' | 'text-height' | 'text-width' | 'th-large' | 'th-list' | 'th' | 'thumb-tack' | 'thumbs-down' | 'thumbs-o-down' | 'thumbs-o-up' | 'thumbs-up' | 'ticket' | 'times-circle-o' | 'times-circle' | 'times' | 'tint' | 'toggle-off' | 'toggle-on' | 'trademark' | 'train' | 'transgender-alt' | 'transgender' | 'trash-o' | 'trash' | 'tree' | 'trello' | 'tripadvisor' | 'trophy' | 'truck' | 'try' | 'tty' | 'tumblr-square' | 'tumblr' | 'twitch' | 'twitter-square' | 'twitter' | 'umbrella' | 'underline' | 'undo' | 'university' | 'unlock-alt' | 'unlock' | 'upload' | 'usd' | 'user-md' | 'user-plus' | 'user-secret' | 'user-times' | 'user' | 'users' | 'venus-double' | 'venus-mars' | 'venus' | 'viacoin' | 'video-camera' | 'vimeo-square' | 'vimeo' | 'vine' | 'vk' | 'volume-down' | 'volume-off' | 'volume-up' | 'weibo' | 'weixin' | 'whatsapp' | 'wheelchair' | 'wifi' | 'wikipedia-w' | 'windows' | 'wordpress' | 'wrench' | 'xing-square' | 'xing' | 'y-combinator' | 'yahoo' | 'yelp' | 'youtube-play' | 'youtube-square' | 'youtube';
export {};
